;; Generated package description from flycheck.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "flycheck" "39.0snapshot0.20260810.102" "On-the-fly syntax checking" '((emacs "28.1") (seq "2.24")) :commit "231d48d526b8f2e0b9ad28e5af79f55e5058556a" :authors '(("Sebastian Wiesner" . "swiesner@lunaryorn.com")) :maintainer '(("Clément Pit-Claudel" . "clement.pitclaudel@live.com") ("fmdkdd" . "fmdkdd@gmail.com") ("Bozhidar Batsov" . "bozhidar@batsov.dev")) :keywords '("convenience" "languages" "tools") :url "https://github.com/flycheck/flycheck")
